@@ -103,6 +103,9 @@ static char rcsid[] = "$Id: gzip.c,v 0.24 1993/06/24 10:52:07 jloup Exp $";
 #    define DIR_OPT "NO_DIR"
 #  endif
 #endif
+#ifndef NO_DIR
+# define NO_DIR 0
+#endif
 
 #ifdef CLOSEDIR_VOID
 # define CLOSEDIR(d) (closedir(d), 0)
@@ -306,7 +309,7 @@ local void do_exit      OF((int exitcode));
       int main          OF((int argc, char **argv));
 int (*work) OF((int infile, int outfile)) = zip; /* function to call */
 
-#ifndef NO_DIR
+#if ! NO_DIR
 local void treat_dir    OF((char *dir));
 #endif
 #ifdef HAVE_UTIME
@@ -320,17 +323,7 @@ local void usage()
 {
     printf ("usage: %s [-%scdfhlLnN%stvV19] [-S suffix] [file ...]\n",
 	    progname,
-#if O_BINARY
-	    "a",
-#else
-	    "",
-#endif
-#ifdef NO_DIR
-	    ""
-#else
-	    "r"
-#endif
-	    );
+	    O_BINARY ? "a" : "", NO_DIR ? "" : "r");
 }
 
 /* ======================================================================== */
@@ -355,7 +348,7 @@ local void help()
  " -n --no-name     do not save or restore the original name and time stamp",
  " -N --name        save or restore the original name and time stamp",
  " -q --quiet       suppress all warnings",
-#ifndef NO_DIR
+#if ! NO_DIR
  " -r --recursive   operate recursively on directories",
 #endif
  " -S .suf  --suffix .suf     use suffix .suf on compressed files",
@@ -539,7 +532,7 @@ int main (argc, argv)
 	case 'q':
 	    quiet = 1; verbose = 0; break;
 	case 'r':
-#ifdef NO_DIR
+#if NO_DIR
 	    fprintf(stderr, "%s: -r not supported on this system\n", progname);
 	    usage();
 	    do_exit(ERROR); break;
@@ -773,7 +766,7 @@ local void treat_file(iname)
 
     /* If the input name is that of a directory, recurse or ignore: */
     if (S_ISDIR(istat.st_mode)) {
-#ifndef NO_DIR
+#if ! NO_DIR
 	if (recursive) {
 	    struct stat st;
 	    st = istat;
@@ -1753,7 +1746,7 @@ local void copy_stat(ifstat)
     }
 }
 
-#ifndef NO_DIR
+#if ! NO_DIR
 
 /* ========================================================================
  * Recurse through the given directory. This code is taken from ncompress.
@@ -1819,7 +1812,7 @@ local void treat_dir(dir)
     if (CLOSEDIR(dirp) != 0)
 	progerror(dir);
 }
-#endif /* ? NO_DIR */
+#endif /* ! NO_DIR */
 
 /* ========================================================================
  * Free all dynamically allocated variables and exit with the given code.
